.. DataRobot Python Package documentation master file, created by
   sphinx-quickstart on Mon Mar 16 10:50:19 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Modeling
========================

The Modeling section provides information to help you easily navigate the process of building, understanding, and analyzing models.

.. toctree::
   :maxdepth: 2

   project.rst
   model.rst
   blueprint.rst
   spec/index.rst
   insights/index.rst
   job.rst
   prime.rst
   model_recommendation.rst
